@@ -34,3 +34,6 @@ class Color:
 
     def __str__(self) -> str:
         return self.hex
+
+    def __repr__(self) -> str:
+        return f"<Color r={self.r} g={self.g} b={self.b}>"
